==> webkit_1.7.5.orig.tar.xz: webkit-1.7.5/Source/WebCore/html/HTMLTableColElement.h <==
/*
 * Copyright (C) 1997 Martin Jones (mjones@kde.org)
 *           (C) 1997 Torben Weis (weis@kde.org)
 *           (C) 1998 Waldo Bastian (bastian@kde.org)
 *           (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2003, 2004, 2005, 2006, 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef HTMLTableColElement_h
#define HTMLTableColElement_h

#include "HTMLTablePartElement.h"

namespace WebCore {

class HTMLTableColElement : public HTMLTablePartElement {
public:
    static PassRefPtr<HTMLTableColElement> create(const QualifiedName& tagName, Document*);

    int span() const { return m_span; }
    void setSpan(int);

    String width() const;

private:
    HTMLTableColElement(const QualifiedName& tagName, Document*);

    virtual void parseAttribute(Attribute*) OVERRIDE;
    virtual PassRefPtr<StylePropertySet> additionalAttributeStyle() OVERRIDE;

    int m_span;
};

} //namespace

#endif

==> webkit-1.8.0.tar.xz: webkit-1.8.0/Source/WebCore/html/HTMLTableColElement.h <==
/*
 * Copyright (C) 1997 Martin Jones (mjones@kde.org)
 *           (C) 1997 Torben Weis (weis@kde.org)
 *           (C) 1998 Waldo Bastian (bastian@kde.org)
 *           (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2003, 2004, 2005, 2006, 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef HTMLTableColElement_h
#define HTMLTableColElement_h

#include "HTMLTablePartElement.h"

namespace WebCore {

class HTMLTableColElement : public HTMLTablePartElement {
public:
    static PassRefPtr<HTMLTableColElement> create(const QualifiedName& tagName, Document*);

    int span() const { return m_span; }
    void setSpan(int);

    String width() const;

private:
    HTMLTableColElement(const QualifiedName& tagName, Document*);

    virtual void parseAttribute(Attribute*) OVERRIDE;
    virtual bool isPresentationAttribute(Attribute*) const OVERRIDE;
    virtual void collectStyleForAttribute(Attribute*, StylePropertySet*) OVERRIDE;
    virtual StylePropertySet* additionalAttributeStyle() OVERRIDE;

    int m_span;
};

} //namespace

#endif
